@@ -13,9 +13,10 @@ import numpy as np
 import imutils
 from imutils.video import FileVideoStream
 import time
+import os
 
 class MediaStream(Base):
-    def __init__(self, stream=None, type='video', options={}):
+    def __init__(self, stream=None, type='video', options={}, logger=None):
         self.stream = stream
         self.type = type
         self.fvs = None
@@ -28,19 +29,30 @@ class MediaStream(Base):
         self.api = self.options.get('api')
         self.frame_set = []
         self.next_frame_set_index = 0
-        
+        self.orig_h_w = None
+        self.resized_h_w = None        
+        self.default_resize = 800
+        self.is_deletable = False
+        self.session = requests.Session()
 
-        if self.options.get('logger'):
-            self.logger = options.get('logger')
+              
+        if logger:
+            self.logger = logger
         elif self.options.get('api'):
             self.logger = options.get('api').get_logger() 
 
+        _,ext= os.path.splitext(self.stream)
+        if ext.lower() in ['.jpg', '.png', '.jpeg']:
+            self.logger.Debug(1, '{} is a file'.format(self.stream))
+            self.type = 'file'
+            return
        
         self.start_frame = int(options.get('start_frame',1))
         self.frame_skip = int(options.get('frame_skip', 1))
         self.max_frames = int(options.get('max_frames', 0))
 
         
+        
         if self.stream.isnumeric(): 
         # assume it is an eid, in which case we 
         # need to access it via ZM API
@@ -57,17 +69,20 @@ class MediaStream(Base):
                     self.logger.Error('No such event {} found with API'.format(self.stream))
                     return
                 e = es.list()[0]
-                self.stream = e.download_video(dir='/tmp')
-                
+                self.stream = e.download_video(dir=self.options.get('download_dir', '/tmp/'))
+                self.is_deletable = True
                 self.type = 'video'
             else:
                 eid = self.stream
                 self.next_frameid_to_read = int(self.start_frame)
-                self.stream = '{}/index.php?view=image&width={}&eid={}'.format(self.api.get_portalbase(), self.options.get('resize', 800), eid)
+                self.stream = '{}/index.php?view=image&eid={}'.format(self.api.get_portalbase(),  eid)
+                #if self.options.get('resize') != 'no':
+                #    self.stream += '&width={}'.format(self.options.get('resize', self.default_resize))
+
                 if self.api.get_auth() != '':
                     self.stream += '&{}'.format(self.api.get_auth())
 
-                self.logger.Debug(1,'Using URL {} for stream'.format(stream))
+                self.logger.Debug(2,'Using URL {} for stream'.format(stream))
                 self.type = 'image'
         
         
@@ -88,7 +103,7 @@ class MediaStream(Base):
             self.logger.Debug (1, 'Starting video stream {}'.format(stream))
             self.fvs = FileVideoStream(self.stream).start()
             time.sleep(1)
-            self.logger.Debug (1, 'First load - skipping to frame {}'.format(self.start_frame))
+            self.logger.Debug (2, 'First load - skipping to frame {}'.format(self.start_frame))
             if self.frame_set:
                 while self.fvs.more() and self.frames_read < int(self.frame_set[self.next_frame_set_index])-1:
                     self.fvs.read() 
@@ -100,13 +115,23 @@ class MediaStream(Base):
                     self.next_frameid_to_read += 1
 
         else:
-            self.logger.Debug (1,'No need to start streams, we are picking images from {}'.format(self.stream))
+            self.logger.Debug (2,'No need to start streams, we are picking images from {}'.format(self.stream))
 
 
+    def image_dimensions(self):
+        return {
+            'original': self.orig_h_w,
+            'resized': self.resized_h_w
+        }
+
     def get_last_read_frame(self):
         return self.last_frameid_read
 
     def more(self):
+
+        if self.type == 'file':
+            return self.more_images_to_read
+
         if (self.frame_set):
             return self.next_frame_set_index < len(self.frame_set)
 
@@ -122,9 +147,26 @@ class MediaStream(Base):
     def stop(self):
         if (self.type == 'video'):
             self.fvs.stop()
+        if self.is_deletable and self.options.get('delete_after_analyze') == 'yes':
+            try:
+                os.remove(self.stream)
+                self.logger.Debug(2,'Deleted {}'.format(self.stream))
+            except Exception as e:
+                self.logger.Error (f'Could not delete file(s):{e}')
 
     def read(self):
-        
+        if (self.type == 'file'):
+            frame = cv2.imread(self.stream)
+            self.last_frame_id_read = 1
+            self.orig_h_w = frame.shape[:2]
+            self.frames_processed += 1
+            self.more_images_to_read = False
+            if self.options.get('resize') != 'no':
+                frame = imutils.resize(frame,width=self.options.get('resize', self.default_resize))
+            self.resized_h_w = frame.shape[:2]            
+            return frame
+
+
         if (self.type == 'video'):
             while True:
                 frame = self.fvs.read()
@@ -134,13 +176,10 @@ class MediaStream(Base):
                     self.logger.Error ('Error reading frames')
                     return
 
+                self.orig_h_w = frame.shape[:2]
                 if self.frame_set and (self.frames_read != int(self.frame_set[self.next_frame_set_index])):
-                    self.logger.Debug (4,'Ignoring frame {}'.format(self.frames_read))
                     continue
-                else:
-                    self.logger.Debug (4,'MATCHED frame {}'.format(self.frames_read))                    
-
-                    # At this stage weare at the frame to read
+                    # At this stage we are at the frame to read
                 if self.frame_set:
                     self.last_frameid_read = self.frame_set[self.next_frame_set_index]
                     self.next_frame_set_index += 1
@@ -157,7 +196,11 @@ class MediaStream(Base):
                 self.logger.Debug(2, 'Processing frame:{}'.format(self.last_frameid_read))
                 self.frames_processed += 1
                 break
-            frame = imutils.resize(frame,width=self.options.get('resize', 800))
+            #print ('******************************* RESIZE:{}'.format(self.options.get('resize')))
+            if self.options.get('resize') != 'no':
+                frame = imutils.resize(frame,width=self.options.get('resize', self.default_resize))
+            self.resized_h_w = frame.shape[:2]
+
             return frame
         
         else: # image
@@ -166,21 +209,26 @@ class MediaStream(Base):
             else:
                 url = '{}&fid={}'.format(self.stream,self.next_frameid_to_read)
             
-            self.logger.Debug (2, 'Reading {}'.format(url))
+            self.logger.Debug (3, 'Reading {}'.format(url))
 
-            response = requests.get(url)
+            response = self.session.get(url)
             if self.frame_set:
                 self.last_frameid_read = self.frame_set[self.next_frame_set_index]
                 self.next_frame_set_index += 1
             else:
                 self.last_frameid_read = self.next_frameid_to_read
                 self.next_frameid_to_read +=self.frame_skip
-            self.frames_processed +=1 
 
+            self.frames_processed +=1 
             if response.status_code == 200:
                 try:
                     img = np.asarray(bytearray(response.content), dtype='uint8')
                     img = cv2.imdecode (img, cv2.IMREAD_COLOR)
+                    self.orig_h_w =  img.shape[:2]
+                    #print ('******************************* RESIZE:{}'.format(self.options.get('resize')))
+                    if self.options.get('resize') != 'no':
+                        img = imutils.resize(img,width=self.options.get('resize', self.default_resize))
+                    self.resized_h_w = img.shape[:2]
                     return img
                 except Exception as e:
                     self.logger.Error ('Could not retrieve url {}: {}'.format(url,e))
